@@ -8,6 +8,7 @@ from ..nodes.segment import AtroposN4, BinaryFillHoles
 
 from ..utils.misc import get_elem, merge_3_elem_to_list
 from ..utils.utils_nodes import NodeParams, parse_key
+from ..utils.utils_spm import set_spm
 
 
 def create_segment_atropos_pipe(params={}, name="segment_atropos_pipe"):
@@ -138,6 +139,8 @@ def create_old_segment_pipe(params_template, params={},
         name='inputnode'
     )
 
+    assert set_spm(), "Error, SPM was not found, cannot run Regis pipeline"
+
     # Segment in to 6 tissues
     segment = NodeParams(spm.Segment(),
                          params=parse_key(params, "segment"),
